@@ -606,6 +606,235 @@ class YOPMailClient:
             logger.error(f"Error handling rate limit: {e}")
             return False
     
+    def get_rss_feed_url(self, mailbox: Optional[str] = None) -> str:
+        """
+        Get RSS feed URL for a YOPmail address.
+        
+        Args:
+            mailbox: Mailbox name (without @yopmail.com). If None, uses current client mailbox.
+            
+        Returns:
+            RSS feed URL for the specified mailbox
+        """
+        target_mailbox = mailbox or self.mailbox
+        # RSS feed URL format: https://yopmail.com/rss?login=mailbox&h=hash
+        # For now, return the basic URL without hash (hash is generated by YOPmail)
+        return f"https://yopmail.com/rss?login={target_mailbox}"
+    
+    def get_rss_feed_data(self, mailbox: Optional[str] = None) -> Dict[str, Any]:
+        """
+        Get RSS feed data for a YOPmail address.
+        
+        Args:
+            mailbox: Mailbox name (without @yopmail.com). If None, uses current client mailbox.
+            
+        Returns:
+            Dictionary with RSS feed information and messages
+            
+        Raises:
+            HTTPError: If the request fails
+            YOPMailError: If RSS feed cannot be retrieved
+        """
+        target_mailbox = mailbox or self.mailbox
+        
+        try:
+            # Use fresh cookies to potentially avoid rate limits
+            self._set_fresh_cookies()
+            
+            # Check rate limiting before making request
+            delay = self.rate_limiter.get_request_delay()
+            if delay > 0:
+                logger.debug(f"Rate limiting delay: {delay:.1f}s")
+                time.sleep(delay)
+            
+            # First, get the RSS feed page to extract the proper RSS URL with hash
+            gen_rss_url = f"https://yopmail.com/gen-rss?login={target_mailbox}"
+            headers = {**DEFAULT_HEADERS}
+            resp = self.client.get(gen_rss_url, headers=headers)
+            
+            # Check for rate limiting
+            if self._handle_rate_limit_response(resp):
+                return self.get_rss_feed_data(mailbox)  # Retry after rate limiting
+            
+            resp.raise_for_status()
+            
+            # Parse the RSS page to extract the actual RSS URL with hash
+            rss_url = self._extract_rss_url_from_page(resp.text, target_mailbox)
+            
+            # Now get the actual RSS feed data
+            rss_resp = self.client.get(rss_url, headers=headers)
+            rss_resp.raise_for_status()
+            
+            # Parse RSS content
+            rss_content = rss_resp.text
+            
+            # Extract messages from RSS content
+            messages = self._parse_rss_content(rss_content)
+            
+            logger.info(f"Retrieved RSS feed for {target_mailbox} with {len(messages)} messages")
+            
+            return {
+                "mailbox": target_mailbox,
+                "rss_url": rss_url,
+                "message_count": len(messages),
+                "messages": messages,
+                "raw_content": rss_content
+            }
+            
+        except httpx.HTTPStatusError as e:
+            raise HTTPError(e.response.status_code, str(e.request.url), e.response.text)
+        except httpx.RequestError as e:
+            raise NetworkError("RSS feed retrieval", str(e))
+        except Exception as e:
+            logger.error(f"Failed to get RSS feed: {e}")
+            raise YOPMailError(f"Failed to get RSS feed: {e}")
+    
+    def _set_fresh_cookies(self):
+        """Set fresh cookies from real browser session to avoid rate limits."""
+        try:
+            from .constants import DEFAULT_COOKIES
+            
+            # Set fresh cookies to potentially avoid rate limits
+            for name, value in DEFAULT_COOKIES.items():
+                self.client.cookies.set(name, value, domain='.yopmail.com', path='/')
+            
+            logger.debug("Fresh cookies set from real browser session")
+            
+        except Exception as e:
+            logger.warning(f"Failed to set fresh cookies: {e}")
+    
+    def _extract_rss_url_from_page(self, page_content: str, mailbox: str) -> str:
+        """
+        Extract the actual RSS URL with hash from the RSS generation page.
+        
+        Args:
+            page_content: HTML content of the RSS generation page
+            mailbox: Mailbox name
+            
+        Returns:
+            Complete RSS URL with hash
+        """
+        import re
+        
+        # Look for the RSS URL pattern in the page content
+        # Pattern: href="/rss?login=mailbox&h=hash"
+        pattern = r'href="(/rss\?login=' + re.escape(mailbox) + r'&h=[^"]+)"'
+        match = re.search(pattern, page_content)
+        
+        if match:
+            rss_path = match.group(1)
+            return f"https://yopmail.com{rss_path}"
+        else:
+            # Fallback to basic RSS URL
+            return f"https://yopmail.com/rss?login={mailbox}"
+    
+    def _parse_rss_content(self, rss_content: str) -> List[Dict[str, Any]]:
+        """
+        Parse RSS content to extract message information.
+        
+        Args:
+            rss_content: Raw RSS content (XML format)
+            
+        Returns:
+            List of message dictionaries
+        """
+        messages = []
+        
+        try:
+            # Parse XML RSS content
+            from bs4 import BeautifulSoup
+            
+            # Suppress XML parsing warnings
+            import warnings
+            from bs4 import XMLParsedAsHTMLWarning
+            warnings.filterwarnings("ignore", category=XMLParsedAsHTMLWarning)
+            
+            soup = BeautifulSoup(rss_content, 'html.parser')
+            
+            # Find all item elements
+            items = soup.find_all('item')
+            
+            for item in items:
+                # Extract subject from title
+                title_elem = item.find('title')
+                subject = title_elem.get_text(strip=True) if title_elem else "No Subject"
+                
+                # Extract link
+                link_elem = item.find('link')
+                url = link_elem.get_text(strip=True) if link_elem else ""
+                
+                # Extract date
+                pub_date_elem = item.find('pubdate')
+                date = pub_date_elem.get_text(strip=True) if pub_date_elem else "Unknown Date"
+                
+                # Extract description for sender info
+                desc_elem = item.find('description')
+                sender = "Unknown"
+                if desc_elem:
+                    desc_text = desc_elem.get_text(strip=True)
+                    # Look for email pattern in description
+                    import re
+                    email_match = re.search(r'([a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,})', desc_text)
+                    if email_match:
+                        sender = email_match.group(1)
+                
+                messages.append({
+                    "subject": subject,
+                    "sender": sender,
+                    "date": date,
+                    "url": url,
+                    "description": desc_elem.get_text(strip=True) if desc_elem else ""
+                })
+            
+            return messages
+            
+        except Exception as e:
+            logger.error(f"Failed to parse RSS content: {e}")
+            # Fallback to simple text parsing
+            return self._parse_rss_content_fallback(rss_content)
+    
+    def _parse_rss_content_fallback(self, rss_content: str) -> List[Dict[str, Any]]:
+        """
+        Fallback RSS content parsing for simple text format.
+        
+        Args:
+            rss_content: Raw RSS content
+            
+        Returns:
+            List of message dictionaries
+        """
+        messages = []
+        
+        try:
+            # Split content by lines and parse each message
+            lines = rss_content.strip().split('\n')
+            
+            for line in lines:
+                line = line.strip()
+                if not line or line.startswith('<?xml') or line.startswith('<'):
+                    continue
+                
+                # Parse message format: "subject sender date url"
+                parts = line.split(' ')
+                if len(parts) >= 4:
+                    subject = parts[0]
+                    sender = parts[1]
+                    date = parts[2]
+                    url = ' '.join(parts[3:])  # URL might contain spaces
+                    
+                    messages.append({
+                        "subject": subject,
+                        "sender": sender,
+                        "date": date,
+                        "url": url
+                    })
+            
+            return messages
+            
+        except Exception as e:
+            logger.error(f"Failed to parse RSS content (fallback): {e}")
+            return []
+    
     def get_proxy_info(self) -> Dict[str, Any]:
         """Get information about current proxy configuration."""
         return self.proxy_manager.get_proxy_info()
